@@ -63,7 +63,7 @@ var _ actuatoriface.Actuator = (*AWSActuator)(nil)
 type AWSActuator struct {
 	Client           client.Client
 	Codec            *minterv1.ProviderCodec
-	AWSClientBuilder func(accessKeyID, secretAccessKey []byte, infraName string) (ccaws.Client, error)
+	AWSClientBuilder func(accessKeyID, secretAccessKey []byte, region, infraName string) (ccaws.Client, error)
 	Scheme           *runtime.Scheme
 }
 
@@ -149,7 +149,7 @@ func (a *AWSActuator) Exists(ctx context.Context, cr *minterv1.CredentialsReques
 
 // needsUpdate will return whether the current credentials satisfy what's being requested
 // in the CredentialsRequest
-func (a *AWSActuator) needsUpdate(ctx context.Context, cr *minterv1.CredentialsRequest, infraName, region string) (bool, error) {
+func (a *AWSActuator) needsUpdate(ctx context.Context, cr *minterv1.CredentialsRequest, region, infraName string) (bool, error) {
 	logger := a.getLogger(cr)
 	// If the secret simply doesn't exist, we definitely need an update
 	exists, err := a.Exists(ctx, cr)
@@ -162,7 +162,7 @@ func (a *AWSActuator) needsUpdate(ctx context.Context, cr *minterv1.CredentialsR
 
 	// Various checks for the kinds of reasons that would trigger a needed update
 	_, accessKey, secretKey := a.loadExistingSecret(cr)
-	awsClient, err := a.AWSClientBuilder([]byte(accessKey), []byte(secretKey), infraName)
+	awsClient, err := a.AWSClientBuilder([]byte(accessKey), []byte(secretKey), region, infraName)
 	if err != nil {
 		return true, err
 	}
@@ -176,7 +176,7 @@ func (a *AWSActuator) needsUpdate(ctx context.Context, cr *minterv1.CredentialsR
 		return true, fmt.Errorf("unable to decode ProviderStatus: %v", err)
 	}
 
-	readAWSClient, err := a.buildReadAWSClient(cr, infraName)
+	readAWSClient, err := a.buildReadAWSClient(cr, region, infraName)
 	if err != nil {
 		log.WithError(err).Error("error creating read-only AWS client")
 		return true, fmt.Errorf("unable to check whether AWS user is properly tagged")
@@ -275,7 +275,7 @@ func (a *AWSActuator) sync(ctx context.Context, cr *minterv1.CredentialsRequest)
 	}
 
 	// Should we update anything
-	needsUpdate, err := a.needsUpdate(ctx, cr, infraName, region)
+	needsUpdate, err := a.needsUpdate(ctx, cr, region, infraName)
 	if err != nil {
 		logger.WithError(err).Error("error determining whether a credentials update is needed")
 		return &actuatoriface.ActuatorError{
@@ -312,7 +312,7 @@ func (a *AWSActuator) sync(ctx context.Context, cr *minterv1.CredentialsRequest)
 		}
 	} else if cloudCredsSecret.Annotations[annotatorconst.AnnotationKey] == annotatorconst.MintAnnotation {
 		logger.Debugf("provisioning with cred minting")
-		err := a.syncMint(ctx, cr, infraName, logger)
+		err := a.syncMint(ctx, cr, region, infraName, logger)
 		if err != nil {
 			msg := "error syncing creds in mint-mode"
 			logger.WithError(err).Error(msg)
@@ -345,7 +345,7 @@ func (a *AWSActuator) syncPassthrough(ctx context.Context, cr *minterv1.Credenti
 }
 
 // syncMint handles both create and update idempotently.
-func (a *AWSActuator) syncMint(ctx context.Context, cr *minterv1.CredentialsRequest, infraName string, logger log.FieldLogger) error {
+func (a *AWSActuator) syncMint(ctx context.Context, cr *minterv1.CredentialsRequest, region, infraName string, logger log.FieldLogger) error {
 	var err error
 
 	awsSpec, err := DecodeProviderSpec(a.Codec, cr)
@@ -383,12 +383,12 @@ func (a *AWSActuator) syncMint(ctx context.Context, cr *minterv1.CredentialsRequ
 		}
 	}
 
-	rootAWSClient, err := a.buildRootAWSClient(cr, infraName)
+	rootAWSClient, err := a.buildRootAWSClient(cr, region, infraName)
 	if err != nil {
 		logger.WithError(err).Warn("error building root AWS client, will error if one must be used")
 	}
 
-	readAWSClient, err := a.buildReadAWSClient(cr, infraName)
+	readAWSClient, err := a.buildReadAWSClient(cr, region, infraName)
 	if err != nil {
 		logger.WithError(err).Error("error building read-only AWS client")
 		return err
@@ -603,12 +603,16 @@ func (a *AWSActuator) Delete(ctx context.Context, cr *minterv1.CredentialsReques
 	logger = logger.WithField("userName", awsStatus.User)
 
 	logger.Info("deleting credential from AWS")
+	region, err := utils.LoadInfrastructureRegion(a.Client, logger)
+	if err != nil {
+		return err
+	}
 	infraName, err := utils.LoadInfrastructureName(a.Client, logger)
 	if err != nil {
 		return err
 	}
 
-	awsClient, err := a.buildRootAWSClient(cr, infraName)
+	awsClient, err := a.buildRootAWSClient(cr, region, infraName)
 	if err != nil {
 		return err
 	}
@@ -734,7 +738,7 @@ func (a *AWSActuator) tagUser(logger log.FieldLogger, awsClient minteraws.Client
 
 // buildRootAWSClient will return an AWS client using the "root" AWS creds which are expected to
 // live in kube-system/aws-creds.
-func (a *AWSActuator) buildRootAWSClient(cr *minterv1.CredentialsRequest, infraName string) (minteraws.Client, error) {
+func (a *AWSActuator) buildRootAWSClient(cr *minterv1.CredentialsRequest, region, infraName string) (minteraws.Client, error) {
 	logger := a.getLogger(cr).WithField("secret", fmt.Sprintf("%s/%s", rootAWSCredsSecretNamespace, rootAWSCredsSecret))
 
 	logger.Debug("loading AWS credentials from secret")
@@ -746,7 +750,7 @@ func (a *AWSActuator) buildRootAWSClient(cr *minterv1.CredentialsRequest, infraN
 	}
 
 	logger.Debug("creating root AWS client")
-	return a.AWSClientBuilder(accessKeyID, secretAccessKey, infraName)
+	return a.AWSClientBuilder(accessKeyID, secretAccessKey, region, infraName)
 }
 
 // buildReadAWSCreds will return an AWS client using the the scaled down read only AWS creds
@@ -756,7 +760,7 @@ func (a *AWSActuator) buildRootAWSClient(cr *minterv1.CredentialsRequest, infraN
 //
 // If these are not available but root creds are, we will use the root creds instead.
 // This allows us to create the read creds initially.
-func (a *AWSActuator) buildReadAWSClient(cr *minterv1.CredentialsRequest, infraName string) (minteraws.Client, error) {
+func (a *AWSActuator) buildReadAWSClient(cr *minterv1.CredentialsRequest, region, infraName string) (minteraws.Client, error) {
 	logger := a.getLogger(cr).WithField("secret", fmt.Sprintf("%s/%s", roAWSCredsSecretNamespace, roAWSCredsSecret))
 	logger.Debug("loading AWS credentials from secret")
 
@@ -778,13 +782,13 @@ func (a *AWSActuator) buildReadAWSClient(cr *minterv1.CredentialsRequest, infraN
 		if err != nil {
 			if errors.IsNotFound(err) {
 				logger.Warn("read-only creds not found, using root creds client")
-				return a.buildRootAWSClient(cr, infraName)
+				return a.buildRootAWSClient(cr, region, infraName)
 			}
 		}
 	}
 
 	logger.Debug("creating read AWS client")
-	client, err := a.AWSClientBuilder(accessKeyID, secretAccessKey, infraName)
+	client, err := a.AWSClientBuilder(accessKeyID, secretAccessKey, region, infraName)
 	if err != nil {
 		return nil, err
 	}
@@ -803,7 +807,7 @@ func (a *AWSActuator) buildReadAWSClient(cr *minterv1.CredentialsRequest, infraN
 			switch aerr.Code() {
 			case "InvalidClientTokenId":
 				logger.Warn("InvalidClientTokenId for read-only AWS account, likely a propagation delay, falling back to root AWS client")
-				return a.buildRootAWSClient(cr, infraName)
+				return a.buildRootAWSClient(cr, region, infraName)
 			}
 			// Any other error we just let following code sort out.
 		}
